package net.sf.jsequnit.config;

import java.util.prefs.Preferences;

/**
 * This class represents the central configuration.
 * It is mainly populated by the {@code SequenceDoclet}
 * and it is used in the course of {@code SequenceTaglet.toString(Tag)}
 * to use the given parameters.
 * 
 * As JavaDoc taglets are loaded with a separated class loader,
 * this classes uses the Preferences API to persistently use
 * the data from classes that are loaded by different class loaders.
 * Thus, two not unique instances of this class are present in the VM.
 * 
 * @author jacek.ratzinger
 *
 */
public class Configuration {

	private static final String TEST_EXECUTION_CLASSPATH = "TestExecPath";
	private static final String OUTPUT_DIRECTORY = "OutDir";
	
	private static Configuration instance = new Configuration();
	
	public static Configuration getInstance() {
		return instance;
	}

	public String getOutputDirectory() {
		return get(OUTPUT_DIRECTORY);
	}
	
	public void setOutputDirectory(String outputDir) {
		put(OUTPUT_DIRECTORY, outputDir);
	}

	public String getTestExecutionClasspath() {
		return get(TEST_EXECUTION_CLASSPATH);
	}

	public void setTestExecutionClasspath(String testExecutionClasspath) {
		put(TEST_EXECUTION_CLASSPATH, testExecutionClasspath);
	}
	
	private void put(String key, String value) {
		Preferences preferences = getPreferences();
		preferences.put(key, value);
	}
	
	private String get(String key) {
		Preferences preferences = getPreferences();
		return preferences.get(key, null);
	}

	private Preferences getPreferences() {
		return Preferences.userNodeForPackage(this.getClass());
	}

}
