package net.sf.jsequnit.jseq.sdedit;

import java.io.File;
import java.io.IOException;

import net.sf.sdedit.Main;
import th.co.edge.jseq.ActivationList;
import th.co.edge.jseq.Diagram;

/**
 * Represents an sequence diagram.
 * It is written down ad PNG file using the Quick Sequence Diagram Editor (sdedit).
 * First a textual description of messages between objects is produced
 * and then the image file is produced. 
 * 
 * @author jacek.ratzinger
 *
 */
public class SdeditPngDiagram implements Diagram {
	
	private SdeditTextDiagram textDiagram;
	
	/**
	 * Creates a sequence diagram representation
	 * based on the provided list of method calls.
	 * 
	 * @param activationList
	 *            A list of activations representing the message flows between objects.
	 */
	public SdeditPngDiagram(ActivationList activationList) {
		this.textDiagram = new SdeditTextDiagram(activationList);
	}

	/**
	 * Save the diagram as PNG file.
	 * First write the diagram as textual description into a txt file.
	 * Use this txt file as input to sdedit to create the PNG sequence diagram.
	 * 
	 * @param pngFile
	 *            the file to write the sequence diagram to
	 * @throws IOException
	 *            if an error occurs during the file operations
	 */
	public void save(File pngFile) throws IOException {
		String outputFilePrefix = pngFile.getName().substring(0, pngFile.getName().length() - 4);
		File tempTextFile = new File(pngFile.getParentFile(), outputFilePrefix + ".txt");
		textDiagram.save(tempTextFile);
		String[] sdeditArgs = {"-t", "png", "-o", pngFile.getAbsolutePath(), tempTextFile.getAbsolutePath()};
		try {
			Main.main(sdeditArgs);
		} catch (Exception e) {
			throw new IOException(e);
		}
	}

}